PacketHeader

Struct PacketHeader 

pub struct PacketHeader {
    pub component: u16,
    pub command: u16,
    pub error: u16,
    pub ty: PacketType,
    pub id: u16,
}
Structure of packet header which comes before the packet content and describes it.

Fields

component: u16

The component of this packet

command: u16

The command of this packet

error: u16

A possible error this packet contains (zero is none)

ty: PacketType

The type of this packet

id: u16

The unique ID of this packet (Notify packets this is just zero)

Implementations

Source

impl PacketHeader

pub const fn notify(component: u16, command: u16) -> Self

Creates a notify header for the provided component and command

component The component to use command The command to use

pub const fn request(id: u16, component: u16, command: u16) -> Self

Creates a request header for the provided id, component and command

id The packet ID component The component to use command The command to use

pub const fn response(&self) -> Self

Creates a response to the provided packet header by changing the type of the header

pub const fn with_type(&self, ty: PacketType) -> Self

Copies the header contents changing its Packet Type

ty The new packet type

pub const fn with_error(&self, error: u16) -> Self

Copies the header contents changing its Packet Type

pub fn path_matches(&self, other: &PacketHeader) -> bool

Checks if the component and command of this packet header matches that of the other packet header

other The packet header to compare to

pub fn write(&self, dst: &mut BytesMut, length: usize)

Encodes the contents of this header appending to the output source

dst The dst to append the bytes to length The length of the content after the header

pub fn read(src: &mut BytesMut) -> Option<(PacketHeader, usize)>

Attempts to read the packet header from the provided source bytes returning None if there aren’t enough bytes

src The bytes to read from