pub struct Request<T: FromRequest> {
pub req: T,
pub header: PacketHeader,
}Expand description
Structure wrapping a from request type to include a packet header to allow the response type to be created
Fields
req: TThe decoded request type
header: PacketHeaderThe packet header from the request
Implementations