Router

Struct Router 

pub struct Router<C, S> { /* private fields */ }
Route implementation for storing components mapped to route handlers

Implementations

Source

impl<C, S> Router<C, S>
where C: PacketComponents, S: Send + 'static,

pub fn new() -> Self

Creates a new router

pub fn route<Format, Req, Res>( &mut self, component: C, route: impl for<'a> Handler<'a, S, Format, Req, Res>, )
where Req: FromRequestInternal, Res: IntoResponse, Format: 'static,

Adds a new route to the router where the route is something that implements the handler type with any lifetime. The value is wrapped with a HandlerRoute and stored boxed in the routes map under the component key

component The component key for the route route The actual route handler function

pub fn handle<'a>( &self, state: &'a mut S, packet: Packet, ) -> Result<Pin<Box<dyn Future<Output = Packet> + Send + 'a>>, HandleError>

Handle function takes the provided packet retrieves the component from its header and finds the matching route (Returning an empty response immediately if none match) and providing the state the route along with the packet awaiting the route future

state The provided state packet The packet to handle