VarIntList

Struct VarIntList 

pub struct VarIntList<T>(pub Vec<T>);
List of Var ints

Tuple Fields

0: Vec<T>

Implementations

Source

impl<T> VarIntList<T>

pub fn new() -> Self

Creates a new VarIntList

pub fn empty() -> Self

Creates a new VarIntList with no capacity

pub fn with_capacity(capacity: usize) -> Self

Creates a new VarIntList with the provided capacity

capacity The capacity for the underlying list

pub fn push(&mut self, value: impl Into<T>)

Pushes a new value into the underlying list

value The value to push

pub fn remove(&mut self, index: usize) -> Option<T>

Removes the value at the provided index and returns the value stored at it if there is one

index The index to remove

pub fn get(&mut self, index: usize) -> Option<&T>

Retrieves the value at the provided index returning a borrow if one is there

index The index to get the value at