pub struct FormatB;Expand description
Empty type used to represent the format of handler that is not provided state
This type is just used to prevent implementation conflicts between stateful and stateless handlers